# Models

API reference for all [`pydantic`](https://docs.pydantic.dev/latest/) models used.

::: vizro.models

::: vizro.models.types
    options:
      filters: ["!^_"]  # Don't show dunder methods as well as single underscore ones
      merge_init_into_class: false
